
"""
Column Header Bars class for the ColumnListView class.
"""

__author__    = "James Mayfield (james@mineralschool.net)"
__version__   = "$Revision: 1.0 $"
__date__      = "$Date: 2003/01/01 $"

from BView import BView
from BBox import BBox
from BStringView import BStringView
from InterfaceKit import *


class ColumnListHeader(BView):
	def __init__(self, rect, name, listview):
		BView.__init__(self, rect, 'ColumnHeader',B_FOLLOW_LEFT_RIGHT, B_WILL_DRAW|B_FRAME_EVENTS)
		self.SetViewColor((216,216,216,0))
		self.columns = []

		self.col_views = []
		self.down = 0
		self.resizer = 0
		self.listview = listview
		
	def MakeColumn(self, columns, widths):
		l,t, r, b = self.Bounds()
		l_tmp = 0
		c_tmp = 0
		for col in columns:
			if c_tmp == 0:
				col_view = BBox((l + l_tmp, t, l + l_tmp + widths[c_tmp], b), col, B_FOLLOW_LEFT, B_WILL_DRAW|B_FRAME_EVENTS, B_FANCY_BORDER)
			else:
				col_view = BBox((l + l_tmp, t, l + l_tmp + widths[c_tmp], b), col, B_FOLLOW_LEFT, B_WILL_DRAW|B_FRAME_EVENTS, B_FANCY_BORDER)
			
			col_label = BStringView((l+3, t+2, l + widths[c_tmp] -3, b-3), col, col, B_FOLLOW_LEFT_RIGHT, B_WILL_DRAW|B_FRAME_EVENTS)
			col_view.AddChild(col_label)
			self.AddChild(col_view)
			self.columns.append(widths[c_tmp])
			self.col_views.append(col_view)
			l_tmp = l_tmp + widths[c_tmp] + 2
			c_tmp = c_tmp + 1
		col_view = BBox((l + l_tmp, t, r-15, b), 'empty', B_FOLLOW_LEFT, B_WILL_DRAW|B_FRAME_EVENTS, B_FANCY_BORDER)
		self.AddChild(col_view)
		self.columns.append(r-15 - l + l_tmp)
		self.col_views.append(col_view)
		
	def GetColumn(self):
		return self.columns
		
	def MouseDown(self, bp):
		self.SetMouseEventMask(B_POINTER_EVENTS,B_LOCK_WINDOW_FOCUS)
	
		l,t, r, b = self.Bounds()
		tmp = 0
		cnt = 0
		for i in self.columns:
			
			if bp[0] > i + (tmp - 5) and bp[0] < (i + tmp + 5):
				
				self.down = 1
				self.resizer = self.col_views[cnt]
				self.resizer_res = cnt
				self.res_sz = tmp
				
				break
			else:
				tmp = tmp + i + 4
				cnt = cnt + 1
				
	def MouseUp(self, bp):
		self.down = 0
		self.resizer = 0
		
	def MouseMoved(self, bp, code, msg):
		stop = 0
		if self.down:
			l, t, r, b = self.resizer.Bounds()
		
			height = t + b
		
			centerpoint = bp[0]
			
			if bp[0] <  self.res_sz + 25:
				stop = 1
			else:
				stop = 0
			
			if stop == 0:
				if self.resizer != self.col_views[0]:
					tcount = 0
					for x in self.col_views:
						if self.resizer == x:
							break
						else:
							tcount = tcount + 1
					self.resizer.ResizeTo(centerpoint - self.res_sz + (2*tcount), height)
				else:
					self.resizer.ResizeTo(centerpoint - self.res_sz, height)
					
				ll, tt, rr, bb = self.resizer.Bounds()
				self.columns[self.resizer_res] = ll + rr
				delta = bp[0]
		
				cnt = 0
				right = 0
				wid = 0
				for i in self.col_views:
					if i == self.resizer:
						right = 1
						cnt = cnt + 1
					elif right != 1:
						cnt = cnt + 1
										
					else:
						le, te, re, be = i.Bounds()
						if wid == 0:
							i.MoveTo(delta + 2,0.0)
							
						else:
							i.MoveTo(delta + wid + 2,0.0)
						wid = wid + le + re + 2
						le, te, re, be = i.Bounds()
						self.columns[cnt] = le + re
						cnt = cnt + 1
					
				self.listview.Invalidate()